# 2023.11.0

**Released on November 3rd, 2023**

[Documentation for this release](https://cotainr.readthedocs.org/en/2023.11.0/)

A major release introducing several new features to significantly improve the user experience.

## New features

- Cotainr now features a much improved formatting of console output when running `cotainr build`, including options to set verbosity (`--verbose`/`--quiet`), directing the output to a log file (`--log-to-file`), colored output, filtering of output from Conda/Singularity to fix the console output being messed up by attempted line updates, and finally the introduction of a spinner prepended to the latest output message, when cotainr is doing work in the background, [PR#45](https://github.com/DeiC-HPC/cotainr/pull/45).
- When including a conda environment in your container (via `cotainr build ... --conda-env=...`), you are now required to explicitly accept the [Miniforge license terms](https://github.com/conda-forge/miniforge/blob/main/LICENSE) as we use Miniforge to bootstrap the conda environment. This license (along with all other required licenses, if any) may be accepted on beforehand by specifying the option `--accept-licenses` when running `cotainr build ...`, [PR#40](https://github.com/DeiC-HPC/cotainr/pull/40).
- The cotainr release notes now include links to the corresponding HTML documentation hosted on Read the Docs, [PR#38](https://github.com/DeiC-HPC/cotainr/pull/38).

## Bug fixes

- Cotainr now correctly recognizes and supports the [SingularityCE](https://sylabs.io/singularity/) variant of the Singularity runtime, [PR#42](https://github.com/DeiC-HPC/cotainr/pull/42).
- Minor documentation fixes, [PR#34](https://github.com/DeiC-HPC/cotainr/pull/34), [PR#39](https://github.com/DeiC-HPC/cotainr/pull/39), [PR#43](https://github.com/DeiC-HPC/cotainr/pull/43).

## Maintenance updates

- Cotainr now implements [PEP394](https://peps.python.org/pep-0394/) to always invoke the python interpreter as "python3", [PR#33](https://github.com/DeiC-HPC/cotainr/pull/33).
- The LUMI PyTorch example has been updated to match the state of LUMI as of 09/2023, [PR#41](https://github.com/DeiC-HPC/cotainr/pull/41).
- Minor internal additions/refactorizations/updates, [PR#36](https://github.com/DeiC-HPC/cotainr/pull/36).
